#!/bin/bash

# Copyright (C) 2000,2001 Mandrakesoft
# Author Renaud Chaillat <rchaillat@mandrakesoft.com>
# Updates by Florin Grad, Philippe Libat and Vincent Saugey

# $Id: events.sh,v 1.92 2002/10/24 08:58:24 philippe Exp $

# Script to generate events folders hierarchy and hints
# $1 : prefix for building package

# Note:
# Actions are performed in this order:
# 1. Pre actions
# 2. Main actions
# 3. Post actions
#
# In each step, order of actions is imposed by event-handler :
# A. Templates  (found in /usr/share/naat/templates)
# B. Scripts    (found in /usr/share/naat/scripts)
# C. Services  
#    C.a stop
#    C.b reload
#    C.c restart
#    C.d start
#
# So the final order is : 1.A 1.B 1.C 2.A 2.B 2.C 3.A 3.B 3.C
# In each of these steps, actions are filtered to occur only once

# Note:
# '--' are turned into '/' for any hint, like 
#  template--etc--sysconfig--network-scripts--ifcfg-eth0 => 
#  /usr/share/naat/templates/etc/sysconfig/network-scripts/ifcfg-eth0
# 


# clean up before generating everything
[ -e events ] && rm -Rf events;
mkdir events;
pushd events;

# ------ System wide parameters --------
mkdir -p SystemName/{pre,main,post};
mkdir -p DomainName/{pre,main,post};
mkdir -p DNSPrimaryIP/{pre,main,post};
mkdir -p DNSSecondaryIP/{pre,main,post};
#mkdir -p GatewayIP/{pre,main,post};
#mkdir -p GatewayDevice/{pre,main,post};

# *** pre actions ***

touch    DNSPrimaryIP/pre/stop--named;
touch    DNSPrimaryIP/pre/stop--dhcpd;
touch    DNSSecondaryIP/pre/stop--named;

# *** main actions ***

touch    SystemName/main/template--etc--sysconfig--network;
touch    SystemName/main/template--etc--hosts;
touch    SystemName/main/template--etc--squid--squid.conf;
touch    SystemName/main/template--etc--cron.daily--clean-naat;

touch    DomainName/main/template--etc--dhcpd.conf;
touch    DomainName/main/template--etc--hosts;
touch    DomainName/main/template--etc--resolv.conf;
touch    DomainName/main/template--etc--squid--squid.conf;
touch    DomainName/main/template--etc--sysconfig--network;


touch    DNSPrimaryIP/main/template--etc--resolv.conf;
touch    DNSPrimaryIP/main/template--etc--dhcpd.conf;
touch    DNSPrimaryIP/main/template--etc--named.conf;
touch    DNSPrimaryIP/main/template--etc--rndc.key;
touch    DNSPrimaryIP/main/template--etc--rndc.conf;
touch    DNSPrimaryIP/main/script--check-services.pl;

touch    DNSSecondaryIP/main/template--etc--resolv.conf;
touch    DNSSecondaryIP/main/template--etc--named.conf;
touch    DNSSecondaryIP/main/template--etc--rndc.key;
touch    DNSSecondaryIP/main/template--etc--rndc.conf;
touch    DNSSecondaryIP/main/script--check-services.pl;

#touch    GatewayIP/main/template--etc--sysconfig--network;
#touch    GatewayIP/main/template--etc--dhcpd.conf;
#touch    GatewayDevice/main/template--etc--sysconfig--network;

# *** post actions ***

touch    SystemName/post/restart--network
touch    SystemName/post/restart--shorewall
touch    SystemName/post/restart--ipsec
touch    SystemName/post/script--hostname.pl

#touch    DomainName/post/start--bastille-firewall
touch    DomainName/post/restart--network
touch    DomainName/post/restart--shorewall
touch    DomainName/post/restart--ipsec

touch    DNSPrimaryIP/main/script--check-services.pl;
#touch    DNSPrimaryIP/post/reload--dhcpd;
touch    DNSPrimaryIP/post/script--permissions.sh;
touch    DNSPrimaryIP/post/start--named;
touch    DNSPrimaryIP/post/start--dhcpd;
touch    DNSPrimaryIP/post/restart--network
touch    DNSPrimaryIP/post/restart--shorewall
touch    DNSPrimaryIP/post/restart--ipsec
#touch 	 DNSPrimaryIP/post/script--dns-update-named.pl;
#touch    DomainName/post/start--bastille-firewall

touch    DNSSecondaryIP/post/script--permissions.sh;
touch    DNSSecondaryIP/post/start--named;

#touch    GatewayIP/post/reload--dhcpd;

# Rajout Sylvain
# Ajout de rgle par l'utilisateur  la main
#mkdir -p FirewallPolicy/{pre,main,post};
#touch    FirewallPolicy/main/template--etc--shorewall--policy;
#touch    FirewallPolicy/post/restart--shorewall;

#mkdir -p FirewallRules/{pre,main,post};
#touch    FirewallRules/main/template--etc--shorewall--rules;
#touch    FirewallRules/main/template--etc--shorewall--nat;
#touch    FirewallRules/post/restart--shorewall;

# firewall's Log 
#mkdir -p FirewallingLog/{pre,main,post};
#touch    FirewallingLog/main/template--etc--shorewall--policy;
#touch    FirewallingLog/main/template--etc--shorewall--rules;
#touch    FirewallingLog/post/restart--shorewall;

# logs' degre (If FirewallingLog is on)
#mkdir -p FirewallLogDegre/{pre,main,post};
#touch    FirewallLogDegre/main/template--etc--shorewall--policy;
#touch    FirewallLogDegre/main/template--etc--shorewall--rules;
#touch    FirewallLogDegre/post/restart--shorewall;

# Default Reject (DROP or REJECT)
#mkdir -p FirewallReject/{pre,main,post};      
#touch    FirewallReject/main/template--etc--shorewall--rules;
#touch    FirewallReject/main/template--etc--shorewall--policy;
#touch    FirewallReject/post/restart--shorewall;

# Rejected services
#mkdir -p FirewallBlockedServices/{pre,main,post};      
#touch    FirewallBlockedServices/main/template--etc--shorewall--rules;
#touch    FirewallBlockedServices/post/restart--shorewall;


# General accepted services
#mkdir -p FirewallAlwaysForwardServices/{pre,main,post};
#touch    FirewallAlwaysForwardServices/main/template--etc--shorewall--rules;
#touch    FirewallAlwaysForwardServices/post/restart--shorewall;

# Always listened port 
#mkdir -p FirewallAudit/{pre,main,post};
#touch    FirewallAudit/main/template--etc--shorewall--rules;
#touch    FirewallAudit/post/restart--shorewall;

			      
# Define which machine could admin the firewall
#mkdir -p IPAdmin/{pre,main,post};      
#touch    IPAdmin/main/template--etc--shorewall--rules;
#touch    IPAdmin/post/restart--shorewall;

# yes if filter is ok on firewall
mkdir -p Filtering/{pre,main,post};
touch    Filtering/main/script--check-services.pl;
touch    Filtering/post/script--service-firewall.pl;




# Masquerade
#mkdir -p Masquerade/{pre,main,post};      
#touch    Masquerade/main/template--etc--shorewall--masq;
#touch    Masquerade/post/restart--shorewall;


# ------ Ethernet ------
let i=0;
while [ $i -lt 5 ]; do
    mkdir -p Eth${i}IP/{pre,main,post};
    mkdir -p Eth${i}Mask/{pre,main,post};
    mkdir -p Eth${i}BootProto/{pre,main,post};
    mkdir -p Eth${i}Hostname/{pre,main,post};
    mkdir -p Eth${i}Driver/{pre,main,post};
    mkdir -p Eth${i}Known/{pre,main,post};
    # Rajout sylvain
#    mkdir -p Eth${i}ZoneName/{pre,main,post};
#    mkdir -p Eth${i}OptionsInterfacesShorewall/{pre,main,post};
#    mkdir -p Eth${i}OptionsHostsShorewall/{pre,main,post};
#    mkdir -p Eth${i}RestrictionShorewall/{pre,main,post};
    # fin rajout
    ln -s    Eth${i}BootProto  Eth${i}OnBoot;
    ln -s    Eth${i}BootProto  Eth${i}DHCPClient;
    ln -s    Eth${i}BootProto  Eth${i}DHCPHostname;
    ln -s    Eth${i}Hostname   Eth${i}HostAlias;
    ln -s    Eth${i}Driver     Eth${i}Port;
    ln -s    Eth${i}Driver     Eth${i}Irq;
    let i=$i+1;
done;

# *** pre actions *** 
# TODO: instead of stopping the network, stop only the interfaces concerned
#       (use links to update-ethernet for instance, and use $0)

let i=0;
while [ $i -lt 5 ]; do
    touch    Eth${i}IP/pre/script--stop-eth${i};
    touch    Eth${i}Mask/pre/script--stop-eth${i};
    touch    Eth${i}BootProto/pre/script--stop-eth${i};
    touch    Eth${i}Hostname/pre/script--stop-eth${i};
    touch    Eth${i}IP/pre/stop--named;
    touch    Eth${i}IP/pre/stop--dhcpd;
    touch    Eth${i}IP/pre/stop--squid;
    touch    Eth${i}IP/pre/stop--snortd;
    touch    Eth${i}IP/pre/stop--prelude;
#    touch    Eth${i}Mask/pre/stop--named;
    touch    Eth${i}Mask/pre/stop--dhcpd;
    touch    Eth${i}Mask/pre/stop--squid;
    touch    Eth${i}Mask/pre/stop--snortd;
    touch    Eth${i}Mask/pre/stop--prelude;
#    touch    Eth${i}Hostname/pre/stop--named;
    touch    Eth${i}Hostname/pre/stop--dhcpd;
    touch    Eth${i}Hostname/pre/stop--squid;
    touch    Eth${i}Known/pre/stop--dhcpd;
    touch    Eth${i}Known/pre/stop--dhcpd;
    touch    Eth${i}Known/pre/stop--snortd;
    touch    Eth${i}Known/pre/stop--prelude;

    let i=$i+1;
done;

# *** main actions *** 

let i=0;
while [ $i -lt 5 ]; do
    touch    Eth${i}IP/main/template--etc--sysconfig--network-scripts--ifcfg-eth$i;
#    touch    Eth${i}IP/main/template--etc--iptoip.xml;
    touch    Eth${i}IP/main/template--etc--hosts;
    touch    Eth${i}IP/main/template--etc--dhcpd.conf;
    touch    Eth${i}IP/main/template--etc--squid--squid.conf;
    touch    Eth${i}IP/main/template--etc--dansguardian--dansguardian.conf;
    touch    Eth${i}IP/main/template--etc--squid--squidGuard.conf;
    touch    Eth${i}IP/main/template--var--www-naat--html--proxy.pac;
    touch    Eth${i}IP/main/template--etc--named.conf;
    touch    Eth${i}IP/main/template--etc--rndc.key;
    touch    Eth${i}IP/main/template--etc--rndc.conf;


    touch    Eth${i}IP/main/template--etc--snortsnarf.conf;
    touch    Eth${i}IP/main/template--etc--sysconfig--snort;
    touch    Eth${i}IP/main/template--etc--snort--snort.conf;
    touch    Eth${i}IP/main/script--check-services.pl;
#    touch    Eth${i}IP/main/template--etc--httpd--conf--httpd-naat.conf;

    touch    Eth${i}Mask/main/template--etc--sysconfig--network-scripts--ifcfg-eth$i;
    touch    Eth${i}Mask/main/template--etc--squid--squid.conf;
    touch    Eth${i}Mask/main/template--etc--dhcpd.conf;
    touch    Eth${i}Mask/main/template--var--www-naat--html--proxy.pac;
    touch    Eth${i}Mask/main/template--etc--sysconfig--snort;
    touch    Eth${i}Mask/main/template--etc--snort--snort.conf;
    touch    Eth${i}Mask/main/template--etc--snortsnarf.conf;
    touch    Eth${i}Mask/main/script--check-services.pl;
#    touch   Eth${i}Mask/main/template--etc--named.conf;
#    touch   Eth${i}Mask/main/template--etc--rndc.key;
#    touch   Eth${i}Mask/main/template--etc--rndc.conf;
#    touch   Eth${i}Mask/main/script--permissions.sh;
#    touch   Eth${i}Mask/main/template--etc--httpd--conf--httpd-naat.conf;

    touch    Eth${i}BootProto/main/template--etc--sysconfig--network-scripts--ifcfg-eth$i;
	# not really dependant on BootProto but rather on DHCPClient and DHCPHostname
    touch    Eth${i}BootProto/main/template--etc--dhclient.conf;
    touch    Eth${i}BootProto/main/template--etc--shorewall--interfaces;
    touch    Eth${i}BootProto/main/script--check-services.pl;

    touch    Eth${i}Hostname/main/template--etc--hosts;
    touch    Eth${i}Hostname/main/template--etc--dhcpd.conf;
    touch    Eth${i}Hostname/main/script--check-services.pl;
#   touch    Eth${i}Hostname/main/template--etc--named.conf;
#   touch    Eth${i}Hostname/main/template--etc--rndc.key;
#   touch    Eth${i}Hostname/main/template--etc--rndc.conf;
#   touch    Eth${i}Hostname/main/script--permissions.sh;

#touch    Eth${i}Known/main/template--etc--Bastille--bastille-firewall.cfg;
touch    Eth${i}Known/main/template--etc--shorewall--zones;
touch    Eth${i}Known/main/template--etc--shorewall--interfaces;
touch    Eth${i}Known/main/template--etc--shorewall--policy;
touch    Eth${i}Known/main/template--etc--shorewall--rules;
touch    Eth${i}Known/main/template--etc--shorewall--hosts;
touch    Eth${i}Known/main/template--etc--shorewall--tunnels;
touch    Eth${i}Known/main/template--etc--shorewall--tcrules;
touch    Eth${i}Known/main/template--etc--shorewall--tos;
touch    Eth${i}Known/main/template--etc--shorewall--nat;
touch    Eth${i}Known/main/template--etc--shorewall--masq;
touch    Eth${i}Known/main/template--etc--shorewall--proxyarp;
touch    Eth${i}Known/main/template--etc--shorewall--blacklist;
touch    Eth${i}Known/main/script--check-services.pl;

    
    touch    Eth${i}Known/main/template--etc--squid--squid.conf;
    touch    Eth${i}Known/main/template--etc--dansguardian--dansguardian.conf;
    touch    Eth${i}Known/main/template--var--www-naat--html--proxy.pac;
#    touch    Eth${i}Known/main/template--etc--iptoip.xml;
    touch    Eth${i}Known/main/template--etc--sysconfig--snort;
    touch    Eth${i}Known/main/template--etc--snort--snort.conf;
    touch    Eth${i}Known/main/template--etc--snortsnarf.conf;


    touch    Eth${i}Known/main/script--update-ethernet.pl; # ifcfg-ethx
    touch    Eth${i}Known/main/script--check-services.pl; # ifcfg-ethx

    # Rajout Sylvain : shorewall
 #   touch    Eth${i}ZoneName/main/template--etc--shorewall--zones;
 #   touch    Eth${i}ZoneName/main/template--etc--shorewall--interfaces;
 #   touch    Eth${i}ZoneName/main/template--etc--shorewall--hosts;
 #   touch    Eth${i}ZoneName/main/template--etc--shorewall--policy;
 #   touch    Eth${i}ZoneName/main/template--etc--shorewall--rules;
 #   touch    Eth${i}IP/main/template--etc--shorewall--interfaces;
 #   touch    Eth${i}Mask/main/template--etc--shorewall--interfaces;
 #   touch    Eth${i}Known/main/template--etc--shorewall--zones;
 #   touch    Eth${i}OptionsInterfacesShorewall/main/template--etc--shorewall--interfaces;
 #   touch    Eth${i}Mask/main/template--etc--shorewall--interfaces;
 #   touch    Eth${i}ZoneName/main/template--etc--shorewall--hosts;
 #   touch    Eth${i}OptionsHostsShorewall/main/template--etc--shorewall--hosts;
 #   touch    Eth${i}RestrictionShorewall/main/template--etc--shorewall--hosts;
    # fin Rajout

    let i=$i+1;
done;

# *** post actions *** 

let i=0;
while [ $i -lt 5 ]; do
# ?!?    touch    Eth${i}Driver/post/script--update-ethernet.pl; # ifcfg-ethx
    touch    Eth${i}IP/post/script--permissions.sh;
    touch    Eth${i}IP/post/script--start-eth${i};
    touch    Eth${i}IP/post/start--dhcpd;
 #  touch    Eth${i}IP/post/script--dns-update-named.pl;
    touch    Eth${i}IP/post/start--squid;
    touch    Eth${i}IP/post/start--snortd;
    touch    Eth${i}IP/post/start--prelude;
    touch    Eth${i}IP/post/start--named;
##    touch    Eth${i}IP/post/restart--httpd-naat;
    touch    Eth${i}Mask/post/script--start-eth${i};
    touch    Eth${i}Mask/post/start--dhcpd;
    touch    Eth${i}Mask/post/start--squid;
    touch    Eth${i}Mask/main/script--permissions.sh;
    touch    Eth${i}Mask/post/start--snortd;
    touch    Eth${i}Mask/post/start--prelude;
##    touch    Eth${i}Mask/post/restart--httpd-naat;
 #  touch    Eth${i}Mask/post/script--dns-update-named.pl;
 #   touch    Eth${i}Mask/post/start--named;
    touch    Eth${i}BootProto/post/script--start-eth${i};
    touch    Eth${i}BootProto/post/start--etc--shorewall;
    touch    Eth${i}Hostname/post/script--start-eth${i};
    touch    Eth${i}Hostname/post/start--dhcpd;
    touch    Eth${i}Hostname/post/start--squid;
 #  touch    Eth${i}Hostname/post/script--dns-update-named.pl;
 #  touch    Eth${i}Hostname/post/start--named;
    touch    Eth${i}Known/post/start--dhcpd;
    touch    Eth${i}Known/post/start--squid;
    touch    Eth${i}Known/post/start--snortd;
    touch    Eth${i}Known/post/start--prelude;

#    touch    Eth${i}ZoneName/post/restart--shorewall;
#    touch    Eth${i}OptionsInterfacesShorewall/post/restart--shorewall;
    touch    Eth${i}IP/post/restart--shorewall;
    touch    Eth${i}Mask/post/restart--shorewall;
#    touch    Eth${i}OptionsHostsShorewall/post/restart--shorewall;
#    touch    Eth${i}RestrictionShorewall/post/restart--shorewall;
    let i=$i+1;
done;


# ------ FREES/Wan ------

# Ensemble des variables pour le VPN via frees/wan
mkdir -p VPN/{pre,main,post};
mkdir -p CreateServerCert/{pre,main,post};
mkdir -p CreateCACert/{pre,main,post};
mkdir -p VPNOtherKeysList/{pre,main,post};
mkdir -p VPNCAList/{pre,main,post};
mkdir -p VPNServerList/{pre,main,post};
mkdir -p VPNClientList/{pre,main,post};

# --- pre ----
# --- main ----
touch    VPN/main/script--check-services.pl;
touch    VPNCAList/main/template--etc--freeswan--config_file_ca;
touch    VPNCAList/main/template--etc--freeswan--config_file_server_x509;
touch    CreateServerCert/main/template--etc--freeswan--config_file_ca;
touch    CreateServerCert/main/template--etc--freeswan--config_file_server_x509;
touch    CreateCACert/main/template--etc--freeswan--config_file_ca;
touch    CreateCACert/main/template--etc--freeswan--config_file_server_x509;
touch    VPNOtherKeysList/main/template--etc--freeswan--config_file_ca;
touch    VPNOtherKeysList/main/template--etc--freeswan--config_file_server_x509;
touch    VPNServerList/main/template--etc--freeswan--ipsec.conf;
touch    VPNServerList/main/template--etc--freeswan--ipsec.secrets;
touch    VPNClientList/main/template--etc--freeswan--ipsec.conf;
touch    VPNClientList/main/template--etc--freeswan--ipsec.secrets;

# --- post ----
touch 	 CreateServerCert/post/script--gentestcrtserver;
touch 	 CreateCACert/post/script--gentestcrtca;
touch    VPNServerList/post/restart--ipsec;
touch    VPNClientList/post/restart--ipsec;

mkdir -p FREESWAN_REP/{pre,main,post};
touch    FREESWAN_REP/pre/stop--ipsec;
touch    FREESWAN_REP/main/template--etc--freeswan--ipsec.secrets;
touch    FREESWAN_REP/post/template--etc--freeswan--ipsec.conf;
touch    FREESWAN_REP/post/start--ipsec;

mkdir -p LOCAL_RSA_KEYS/{pre,main,post};
touch    LOCAL_RSA_KEYS/pre/stop--ipsec;
touch    LOCAL_RSA_KEYS/main/template--etc--freeswan--ipsec.secrets;
touch    LOCAL_RSA_KEYS/post/template--etc--freeswan--ipsec.conf;
touch    LOCAL_RSA_KEYS/post/start--ipsec;

mkdir -p PLUTOT_DEBUG/{pre,main,post};
touch    PLUTOT_DEBUG/pre/stop--ipsec;
touch    PLUTOT_DEBUG/post/template--etc--freeswan--ipsec.conf;
touch    PLUTOT_DEBUG/post/start--ipsec;




let i=0;
while [ $i -lt 5 ]; do
    mkdir -p IPSec${i}ZoneName/{pre,main,post};
    mkdir -p IPSec${i}Interface/{pre,main,post};
    mkdir -p IPSec${i}RightIP/{pre,main,post};
    mkdir -p IPSec${i}Authby/{pre,main,post};
    mkdir -p IPSec${i}Keyingtries/{pre,main,post};
    mkdir -p IPSec${i}Auto/{pre,main,post};
    mkdir -p IPSec${i}SharedSecret/{pre,main,post};
    mkdir -p IPSec${i}LeftSubnet/{pre,main,post};
    mkdir -p IPSec${i}LeftID/{pre,main,post};
    mkdir -p IPSec${i}RightSubnet/{pre,main,post};
    mkdir -p IPSec${i}RightID/{pre,main,post};
    mkdir -p IPSec${i}RightPubkey/{pre,main,post};
    let i=$i+1;
done;

# *** pre action ***

let i=0;
while [ $i -lt 5 ]; do
    touch    IPSec${i}ZoneName/pre/stop--ipsec;
    touch    IPSec${i}Interface/pre/stop--ipsec;
    touch    IPSec${i}LeftSubnet/pre/stop--ipsec;
    touch    IPSec${i}LeftID/pre/stop--ipsec;
    touch    IPSec${i}RightIP/pre/stop--ipsec;
    touch    IPSec${i}RightID/pre/stop--ipsec;
    touch    IPSec${i}RightSubnet/pre/stop--ipsec;
    touch    IPSec${i}Auto/pre/stop--ipsec;
    touch    IPSec${i}Authby/pre/stop--ipsec;
    touch    IPSec${i}Keyingtries/pre/stop--ipsec;
    touch    IPSec${i}SharedSecret/pre/stop--ipsec;
    touch    IPSec${i}RightPubkey/pre/stop--ipsec;
    let i=$i+1;
done;



# *** main action ***

let i=0;
while [ $i -lt 5 ]; do
    # Must re-create ipsec.secret ( or sub files ).
    touch    IPSec${i}Authby/pre/script--ipsec_secrets.pl;
    touch    IPSec${i}LeftID/pre/script--ipsec_secrets.pl;
    touch    IPSec${i}RightIP/pre/script--ipsec_secrets.pl;
    touch    IPSec${i}RightID/pre/script--ipsec_secrets.pl;
    touch    IPSec${i}Interface/pre/script--ipsec_secrets.pl;

    # ipsec.secrets must be executed before ipsec.conf
    touch    IPSec${i}Authby/main/template--etc--freeswan--ipsec.secrets;
    touch    IPSec${i}LeftID/main/template--etc--freeswan--ipsec.secrets;
    touch    IPSec${i}RightIP/main/template--etc--freeswan--ipsec.secrets;
    touch    IPSec${i}RightID/main/template--etc--freeswan--ipsec.secrets;
    touch    IPSec${i}Interface/main/template--etc--freeswan--ipsec.secrets;
    touch    IPSec${i}SharedSecret/main/template--etc--freeswan--ipsec.secrets;
    touch    IPSec${i}RightPubkey/template--etc--freeswan--ipsec.secrets;


    touch    IPSec${i}ZoneName/main/template--etc--shorewall--tunnels;
    touch    IPSec${i}Interface/main/template--etc--shorewall--tunnels;
    touch    IPSec${i}RightIP/main/template--etc--shorewall--tunnels;

    touch    IPSec${i}ZoneName/main/template--etc--shorewall--zones;
    touch    IPSec${i}Interface/main/template--etc--shorewall--zones;

    touch    IPSec${i}ZoneName/main/template--etc--shorewall--interfaces;
    touch    IPSec${i}Interface/main/template--etc--shorewall--interfaces;

    touch    IPSec${i}ZoneName/main/template--etc--shorewall--rules;
    touch    IPSec${i}Interface/main/template--etc--shorewall--rules;
    touch    IPSec${i}ZoneName/main/template--etc--shorewall--tunnels;
    touch    IPSec${i}Interface/main/template--etc--shorewall--tunnels;
    touch    IPSec${i}RightIP/main/template--etc--shorewall--tunnels;
    let i=$i+1;
done;

# *** post action ***
let i=0;
while [ $i -lt 5 ]; do
    touch    IPSec${i}ZoneName/post/restart--shorewall;
    touch    IPSec${i}Interface/post/restart--shorewall;

    touch    IPSec${i}ZoneName/post/start--ipsec;
    touch    IPSec${i}Interface/post/start--ipsec;
    touch    IPSec${i}LeftSubnet/post/start--ipsec;
    touch    IPSec${i}LeftID/post/start--ipsec;
    touch    IPSec${i}RightIP/post/start--ipsec;
    touch    IPSec${i}RightID/post/start--ipsec;
    touch    IPSec${i}RightSubnet/post/start--ipsec;
    touch    IPSec${i}Auto/post/start--ipsec;
    touch    IPSec${i}Authby/post/start--ipsec;
    touch    IPSec${i}Keyingtries/post/start--ipsec;
    touch    IPSec${i}SharedSecret/post/start--ipsec;
    touch    IPSec${i}RightPubkey/post/start--ipsec;

    touch    IPSec${i}ZoneName/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}Interface/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}LeftSubnet/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}LeftID/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}RightIP/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}RightID/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}RightSubnet/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}Auto/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}Authby/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}Keyingtries/post/template--etc--freeswan--ipsec.conf;
    touch    IPSec${i}SharedSecret/post/template--etc--freeswan--ipsec.conf;
    let i=$i+1;
done;

    


# ------ DHCP Server ------
mkdir -p DHCPServerStart/{pre,main,post};
ln -s    DHCPServerStart DHCPServerEnd;
ln -s    DHCPServerStart DHCP_LEASE_DEFAULT;
ln -s    DHCPServerStart DHCP_LEASE_MAX;
mkdir -p DHCPDomainName/{pre,main,post};
mkdir -p DHCPServer/{pre,main,post};
mkdir -p DHCPWINSServer/{pre,main,post};
mkdir -p DHCPInterface/{pre,main,post};

# *** pre actions *** 
touch    DHCPInterface/pre/stop--dhcpd;
touch    DHCPServerStart/pre/stop--dhcpd;
touch    DHCPServer/pre/stop--dhcpd;
touch    DHCPDomainName/pre/stop--dhcpd;
touch    DHCPWINSServer/pre/stop--dhcpd;

# *** main actions *** 

touch    DHCPInterface/main/template--etc--init.d--dhcpd;
touch    DHCPInterface/main/template--etc--dhcpd.conf;
touch    DHCPInterface/main/script--check-services.pl;
#touch    DHCPServer/main/template--etc--Bastille--bastille-firewall.cfg;
touch    DHCPServer/main/template--etc--init.d--dhcpd;
touch    DHCPServerStart/main/template--etc--dhcpd.conf;
touch    DHCPServerStart/main/script--check-services.pl;
touch    DHCPDomainName/main/template--etc--dhcpd.conf;
touch    DHCPDomainName/main/script--check-services.pl;
touch    DHCPWINSServer/main/template--etc--dhcpd.conf;
touch    DHCPWINSServer/main/script--check-services.pl;

touch    DHCPServer/main/script--check-services.pl;

# *** post actions *** 

touch    DHCPInterface/post/start--dhcpd;
touch    DHCPServerStart/post/start--dhcpd;
touch    DHCPServer/post/start--dhcpd;
touch    DHCPDomainName/post/start--dhcpd;
touch    DHCPWINSServer/post/start--dhcpd;

# ------ Syslog ------
mkdir -p SYSLOGTty/{pre,main,post}
for i in TtyLevel TargetServer TargetServerLevel Local;
do
    [ ! -f SYSLOG$i ] && ln -s SYSLOGTty SYSLOG$i
done


# *** pre actions *** 
#touch    SYSLOGTty/pre/stop--syslog;

# *** main actions *** 

touch    SYSLOGTty/main/template--etc--syslog.conf;
#touch    SYSLOGTty/main/template--etc--shorewall--rules;
touch    SYSLOGTty/main/script--check-services.pl

# *** post actions *** 

touch    SYSLOGTty/post/restart--syslog
#touch    SYSLOGTty/post/restart--shorewall;


# ------ Prelude IDS ------
mkdir -p PreludeState/{pre,main,post}

# *** pre actions *** 
#touch    PreludeState/post/stop--prelude;

# *** main actions *** 

touch    PreludeState/main/template--etc--prelude--prelude-report.conf
touch    PreludeState/main/script--check-services.pl

# *** post actions *** 

touch    PreludeState/post/restart--prelude; # will start only if 'on' (check-services will have added the service to the current runlevel)



# ------ Snort IDS ------
mkdir -p SnortState/{pre,main,post}

# *** pre actions *** 
#touch    SnortState/pre/stop--snortd;
#touch    SnortState/pre/stop--prelude;

# *** main actions *** 

touch    SnortState/main/template--etc--snort--snort.conf
touch    SnortState/main/template--etc--sysconfig--snort
touch    SnortState/main/template--etc--snortsnarf.conf
touch    SnortState/main/script--check-services.pl

# *** post actions *** 

touch    SnortState/post/script--permissions.sh;
touch    SnortState/post/restart--snortd; # will start only if 'on' (check-services will have added the service to the current runlevel)
touch    SnortState/post/restart--prelude; # will start only if 'on' (check-services will have added the service to the current runlevel)


# ------ Dynamic DNS ------
#mkdir -p DNS_SERVER_DYN_UPDATE/{pre,main,post}
#ln -s DNS_SERVER_DYN_UPDATE DNS_UPDATER_SECRET

# *** pre actions *** 

#touch    DNS_SERVER_DYN_UPDATE/post/stop--named;

# *** main actions *** 

#touch    DNS_SERVER_DYN_UPDATE/main/template--etc--dhcpd.conf;    
#touch    DNS_SERVER_DYN_UPDATE/main/template--etc--named.conf;    
#touch    DNS_SERVER_DYN_UPDATE/main/template--etc--rndc.key;
#touch    DNS_SERVER_DYN_UPDATE/main/template--etc--rndc.conf;
#touch    DNS_SERVER_DYN_UPDATE/main/script--permissions.sh;

# *** post actions *** 

#touch    DNS_SERVER_DYN_UPDATE/post/reload--dhcpd;
#touch    DNS_SERVER_DYN_UPDATE/post/script--dns-update-named.pl;
#touch    DNS_SERVER_DYN_UPDATE/post/start--named;


# ------ DNS Server ------
mkdir -p DNSServer/{pre,main,post};

# *** pre actions *** 

#touch    DNSServer/pre/stop--named;

# *** main actions *** 

touch    DNSServer/main/template--etc--named.conf;
touch    DNSServer/main/template--etc--rndc.key;
touch    DNSServer/main/template--etc--rndc.conf;
touch    DNSServer/main/template--etc--resolv.conf;
touch    DNSServer/main/template--etc--dhcpd.conf;
#touch    DNSServer/main/template--etc--Bastille--bastille-firewall.cfg;
touch    DNSServer/main/script--check-services.pl;

# *** post actions *** 

#touch    DNSServer/post/start--bastille-firewall
touch    DNSServer/post/restart--shorewall
#touch    DNSServer/post/script--dns-update-named.pl;
touch    DNSServer/post/script--permissions.sh;
touch    DNSServer/post/restart--named;
touch    DNSServer/post/restart--dhcpd;

# ------ DynDns Service ------
mkdir -p DynDnsService/{pre,main,post};
ln -sf DynDnsService DynDnsAccount
ln -sf DynDnsService DynDnsPassword
ln -sf DynDnsService DynDnsSystemName
ln -sf DynDnsService DynDnsNotifyMail

# *** pre actions *** 
touch    DynDnsService/pre/stop--ez-ipupdate;

# *** main actions *** 
touch    DynDnsService/main/template--etc--ez-ipupdate.conf;
touch    DynDnsService/main/script--check-services.pl;

# *** post actions *** 
touch    DynDnsService/post/start--ez-ipupdate;


# ------ Time Synchronization ------
# *** pre actions *** 
# *** main actions *** 
# *** post actions *** 
mkdir -p Zone/{pre,main,post};
mkdir -p NTPServer/{pre,main,post};
touch Zone/main/template--etc--sysconfig--clock;
touch NTPServer/main/template--etc--cron.d--ntp-synchro;
#touch NTPServer/main/template--etc--Bastille--bastille-firewall.cfg;
#touch Zone/post/script--date.pl;

# ------ Squid ------
mkdir -p SquidServer/{pre,main,post};
mkdir -p SquidPort/{pre,main,post};
mkdir -p SquidAlertEmail/{pre,main,post};
mkdir -p SquidServerAuthentication/{pre,main,post};
mkdir -p SquidServerAuthenticationOptions/{pre,main,post};

# *** pre actions *** 
# *** main actions *** 

touch SquidPort/main/template--etc--squid--squid.conf;
touch SquidPort/main/template--etc--dansguardian--dansguardian.conf;
touch SquidPort/main/script--check-services.pl;
touch SquidServer/main/template--usr--lib--squid--errors--French--ERR_CUSTOM_ACCESS_DENIED;
touch SquidServer/main/template--usr--lib--squid--errors--English--ERR_CUSTOM_ACCESS_DENIED;
touch SquidServer/main/template--etc--squid--squid.conf;
touch SquidServer/main/template--etc--squid--squidGuard.conf;
#touch SquidServer/main/template--etc--Bastille--bastille-firewall.cfg;
touch SquidServer/main/template--var--www-naat--squidGuard--squidGuard.cgi;
touch SquidServer/main/script--permissions.sh;
touch SquidServer/main/template--var--www-naat--html--proxy.pac;
touch SquidServer/main/template--etc--cron.daily--0sarg;
touch SquidServer/main/template--etc--cron.weekly--0sarg;
touch SquidServer/main/template--etc--cron.monthly--0sarg;
touch SquidAlertEmail/main/script--permissions.sh;
touch SquidAlertEmail/main/template--var--www-naat--squidGuard--squidGuard.cgi;
touch SquidAlertEmail/main/script--permissions.sh;
touch SquidAlertEmail/main/script--check-services.pl;
touch SquidServer/main/script--check-services.pl;
touch SquidServerAuthentication/main/template--etc--squid--squid.conf;
touch SquidServerAuthentication/main/script--check-services.pl;
touch SquidServerAuthenticationOptions/main/template--etc--squid--squid.conf;
touch SquidServerAuthenticationOptions/main/script--check-services.pl;

# *** post actions *** 
touch SquidAlertEmail/post/script--permissions.sh;
touch SquidPort/post/restart--squid;
touch SquidPort/post/script--permissions.sh;
touch SquidServer/post/script--permissions.sh;
touch SquidServer/post/restart--squid;
#touch SquidServer/post/start--bastille-firewall
touch SquidServer/post/restart--shorewall
touch SquidServerAuthentication/post/restart--squid;
touch SquidServerAuthenticationOptions/post/restart--squid;

# create the same structure for all the other squid variables
ln -s SquidPort SquidCacheDir;
ln -s SquidPort SquidCacheSize;
ln -s SquidPort SquidWarningMesage;
ln -s SquidPort SquidWarningMesagePosition;
ln -s SquidPort SquidAlertEmail;
ln -s SquidPort SquidRedirector;
ln -s SquidPort SquidAnonymizer;

# ------ WebFilter ------
mkdir -p UrlFilter/{pre,main,post};
mkdir -p BannerFilter/{pre,main,post};
mkdir -p ContentFilter/{pre,main,post};
mkdir -p ContentFilterPort/{pre,main,post};
mkdir -p SquidGuardDb/{pre,main,post};
mkdir -p SquidGuardAlertEmail/{pre,main,post};

# *** pre actions *** 
# *** main actions *** 

touch UrlFilter/main/template--etc--squid--squid.conf;
touch UrlFilter/main/template--etc--squid--squidGuard.conf;
touch UrlFilter/main/template--var--www-naat--squidGuard--squidGuard.cgi;
touch UrlFilter/main/template--etc--httpd--conf--vhosts--httpd-naat.Vhosts.conf;
touch UrlFilter/main/script--permissions.sh;
touch UrlFilter/main/script--check-services.pl;
touch BannerFilter/main/template--etc--squid--squid.conf;
touch BannerFilter/main/template--etc--squid--squidGuard.conf;
touch ContentFilter/main/template--etc--squid--squid.conf;
touch ContentFilter/main/template--etc--dansguardian--dansguardian.conf;
touch ContentFilter/main/template--var--www-naat--squidGuard--dansguardian.cgi;
touch ContentFilter/main/template--etc--dansguardian--template.html;
touch ContentFilter/main/script--permissions.sh;
touch ContentFilterPort/main/template--etc--squid--squid.conf;
touch ContentFilterPort/main/template--etc--dansguardian--dansguardian.conf;
touch ContentFilter/main/template--etc--httpd--conf--vhosts--httpd-naat.Vhosts.conf;
touch ContentFilterPort/main/script--permissions.sh;
touch ContentFilter/main/template--etc--squid--squidGuard.conf;
touch ContentFilter/main/script--check-services.pl;
touch SquidGuardDb/main/template--etc--squid--squidGuard.conf;
touch SquidGuardDb/main/template--var--www-naat--squidGuard--squidGuard.cgi;
touch SquidGuardDb/main/script--permissions.sh;
touch SquidGuardDb/main/script--check-services.pl;

# *** post actions *** 

touch UrlFilter/post/reload--squid;
touch UrlFilter/post/reload--httpd-naat;
touch BannerFilter/post/reload--squid;
touch ContentFilter/post/script--permissions.sh;
touch ContentFilter/post/restart--squid;
#touch ContentFilter/post/reload--httpd-naat;
touch ContentFilterPort/post/script--permissions.sh;
touch ContentFilterPort/post/restart--squid;
touch SquidGuardDb/post/reload--squid;
touch SquidGuardDb/post/reload--httpd-naat;

ln -s SquidGuardDb SquidGuardLogDir;
ln -s SquidGuardDb SquidGuardTimeRestriction;
ln -s SquidGuardDb SquidGuardWorkHoursSunAM;
ln -s SquidGuardDb SquidGuardWorkHoursSunPM;
ln -s SquidGuardDb SquidGuardWorkHoursMonAM;
ln -s SquidGuardDb SquidGuardWorkHoursMonPM;
ln -s SquidGuardDb SquidGuardWorkHoursTueAM;
ln -s SquidGuardDb SquidGuardWorkHoursTuePM;
ln -s SquidGuardDb SquidGuardWorkHoursWedAM;
ln -s SquidGuardDb SquidGuardWorkHoursWedPM;
ln -s SquidGuardDb SquidGuardWorkHoursThuAM;
ln -s SquidGuardDb SquidGuardWorkHoursThuPM;
ln -s SquidGuardDb SquidGuardWorkHoursFriAM;
ln -s SquidGuardDb SquidGuardWorkHoursFriPM;
ln -s SquidGuardDb SquidGuardWorkHoursSatAM;
ln -s SquidGuardDb SquidGuardWorkHoursSatPM;
ln -s SquidGuardDb SquidGuardBannedSourceRedirectUrl;
ln -s SquidGuardDb SquidGuardBannedSourceLog;
ln -s SquidGuardDb SquidGuardLanSourceRedirectUrl;
ln -s SquidGuardDb SquidGuardLanSourceLog;
ln -s SquidGuardDb SquidGuardAdvertisingRedirectUrl;
ln -s SquidGuardDb SquidGuardAdvertisingLog;
ln -s SquidGuardDb SquidGuardDefaultRedirectUrl;

# ------ Bastille Firewall parameters ------
mkdir -p FilteringRules/{pre,main,post};
mkdir -p TCP_AUDIT_SERVICES/{pre,main,post};
mkdir -p TCP_PUBLIC_SERVICES/{pre,main,post};
ln -s TCP_PUBLIC_SERVICES UDP_PUBLIC_SERVICES;
mkdir -p FirewallMasquerade/{pre,main,post};
for i in UDP_AUDIT_SERVICES \
TCP_INTERNAL_SERVICES UDP_INTERNAL_SERVICES \
TCP_FORWARD_SERVICES UDP_FORWARD_SERVICES \
TCP_BLOCKED_SERVICES UDP_BLOCKED_SERVICES \
ICMP_AUDIT_TYPES ICMP_ALLOWED_TYPES ICMP_OUTBOUND_DISABLED_TYPES \
FORCE_PASV_FTP ENABLE_SRC_ADDR_VERIFY REJECT_METHOD \
IP_MASQ_NETWORK IP_MASQ_MODULES FirewallingLog FirewallAlwaysForwardPortTCP \
FirewallAlwaysForwardPortUDP FirewallAlwaysOpenInternalPortUDP FirewallingOptimizeTOS;
do
    [ ! -f $i ] && ln -s TCP_AUDIT_SERVICES $i;
done

# ------ Shorewall Firewall parameters ------
mkdir -p ZonesList/{pre,main,post};
mkdir -p InterfacesList/{pre,main,post};
mkdir -p PolicyList/{pre,main,post};
mkdir -p RulesList/{pre,main,post};
mkdir -p HostsList/{pre,main,post};
mkdir -p TunnelsList/{pre,main,post};
mkdir -p TcrulesList/{pre,main,post};
mkdir -p TosList/{pre,main,post};
mkdir -p NatList/{pre,main,post};
mkdir -p MasqList/{pre,main,post};
mkdir -p ProxyarpList/{pre,main,post};
mkdir -p BlacklistList/{pre,main,post};

# *** main actions *** 
touch    ZonesList/main/template--etc--shorewall--zones;
touch    InterfacesList/main/template--etc--shorewall--interfaces;
touch    PolicyList/main/template--etc--shorewall--policy;
touch    RulesList/main/template--etc--shorewall--rules;
touch    HostsList/main/template--etc--shorewall--hosts;
touch    TunnelsList/main/template--etc--shorewall--tunnels;
touch    TcrulesList/main/template--etc--shorewall--tcrules;
touch    TosList/main/template--etc--shorewall--tos;
touch    NatList/main/template--etc--shorewall--nat;
touch    MasqList/main/template--etc--shorewall--masq;
touch    ProxyarpList/main/template--etc--shorewall--proxyarp;
touch    BlacklistList/main/template--etc--shorewall--blacklist;

# *** post actions *** 
touch    ZonesList/post/restart--shorewall;
touch    InterfacesList/post/restart--shorewall;
touch    PolicyList/post/restart--shorewall;
touch    RulesList/post/restart--shorewall;
touch    HostsList/post/restart--shorewall;
touch    TunnelsList/post/restart--shorewall;
touch    TcrulesList/post/restart--shorewall;
touch    TosList/post/restart--shorewall;
touch    NatList/post/restart--shorewall;
touch    MasqList/post/restart--shorewall;
touch    ProxyarpList/post/restart--shorewall;
touch    BlacklistList/post/restart--shorewall;


# *** pre actions *** 

#touch    TCP_PUBLIC_SERVICES/pre/stop--iptoip;

# Remove stop for avoid possible security hole
#touch    TCP_AUDIT_SERVICES/pre/stop--bastille-firewall;

# *** main actions *** 

#touch    TCP_AUDIT_SERVICES/main/template--etc--Bastille--bastille-firewall.cfg;
#touch    TCP_PUBLIC_SERVICES/main/template--etc--Bastille--bastille-firewall.cfg;
#touch    TCP_PUBLIC_SERVICES/main/template--etc--iptoip.xml;
#touch    FirewallMasquerade/main/template--etc--Bastille--bastille-firewall.cfg;
#touch    FirewallMasquerade/main/template--etc--iptoip.xml;

touch    FilteringRules/main/script--check-services.pl;

# *** post actions *** 

#touch    TCP_AUDIT_SERVICES/post/start--bastille-firewall;
touch    TCP_AUDIT_SERVICES/post/restart--shorewall;

#touch    TCP_PUBLIC_SERVICES/post/start--iptoip;
#touch    TCP_PUBLIC_SERVICES/post/start--bastille-firewall;
touch    TCP_PUBLIC_SERVICES/post/restart--shorewall;

#touch    FirewallMasquerade/post/start--bastille-firewall;
touch    FirewallMasquerade/post/restart--shorewall;

#in main# touch    FilteringRules/post/script--check-services.pl;


# ------ Internet access ------
mkdir -p InternetAccessType/{pre,main,post};
mkdir -p InternetInterface/{pre,main,post};
mkdir -p InternetOnBoot/{pre,main,post};
mkdir -p InternetGateway/{pre,main,post};
mkdir -p HostToPing/{pre,main,post};

# *** pre actions *** 

# NOTE : pre step is executed *before* net_cnx_down is updated, which is what we want
# TODO : put a 'internet' initscript which launches adsl, isdn or whatever if onboot ?
#touch    InternetAccessType/pre/stop--internet;
#touch    InternetInterface/pre/stop--internet;
touch    InternetAccessType/pre/stop--adsl;
touch    InternetAccessType/pre/stop--diald;
touch    InternetAccessType/pre/stop--dhcpd;
touch    InternetAccessType/pre/stop--named;
touch    InternetAccessType/pre/stop--prelude;
#touch    InternetAccessType/pre/stop--iptoip;

touch    InternetInterface/pre/stop--adsl;
touch    InternetInterface/pre/stop--diald;
touch    InternetInterface/pre/stop--dhcpd;
touch    InternetInterface/pre/stop--named;
touch    InternetInterface/pre/stop--prelude;
touch    InternetInterface/pre/stop--snortd;
touch    InternetInterface/pre/stop--prelude;
#touch    InternetInterface/pre/stop--iptoip;
touch    InternetInterface/pre/stop--ipsec;



# *** main actions *** 
#touch    InternetInterface/main/template--etc--shorewall--zones;
#touch    InternetInterface/main/template--etc--shorewall--interfaces;
#touch    InternetInterface/main/template--etc--shorewall--hosts;
#touch    InternetInterface/main/template--etc--shorewall--rules;
#touch    InternetInterface/main/template--etc--shorewall--tunnels;
#touch    InternetInterface/main/template--etc--shorewall--nat;

touch    InternetInterface/main/template--etc--freeswan--ipsec.conf;
touch    InternetInterface/main/script--check-services.pl;

#touch    InternetAccessType/main/template--etc--Bastille--bastille-firewall.cfg;
#ttouch    InternetInterface/main/template--etc--Bastille--bastille-firewall.cfg;

touch    InternetAccessType/main/template--etc--dhcpd.conf;
touch    InternetAccessType/main/template--etc--diald--diald.conf;
touch    InternetAccessType/main/template--etc--hosts;
touch    InternetAccessType/main/template--etc--named.conf;
touch    InternetAccessType/main/template--etc--rndc.key;
touch    InternetAccessType/main/template--etc--rndc.conf;
touch    InternetAccessType/main/template--etc--shorewall--shorewall.conf;
touch    InternetAccessType/main/script--permissions.sh;
touch    InternetAccessType/main/template--etc--resolv.conf;
touch    InternetAccessType/main/template--etc--ppp--ip-up.local;
touch    InternetAccessType/main/template--sbin--ifup-local;
touch    InternetAccessType/main/template--etc--ppp--pap-secrets;
touch    InternetAccessType/main/template--etc--ppp--chap-secrets;
touch    InternetAccessType/main/template--etc--ppp--peers--adsl;
touch    InternetAccessType/main/template--etc--ppp--options;
#touch    InternetAccessType/main/template--etc--iptoip.xml;
touch    InternetAccessType/main/template--etc--sysconfig--network;
touch    InternetAccessType/main/template--etc--sysconfig--network-scripts--ifcfg-ppp0;
touch    InternetAccessType/main/template--etc--sysconfig--network-scripts--net_cnx_up;
touch    InternetAccessType/main/template--etc--sysconfig--network-scripts--net_cnx_down;
touch    InternetAccessType/main/template--etc--init.d--adsl;
touch    InternetAccessType/main/script--check-services.pl;
#touch    InternetAccessType/main/template--etc--init.d--internet;
#touch    InternetAccessType/main/template--etc--ppp--pppoe.conf;

touch    InternetGateway/main/template--etc--sysconfig--network;
touch    InternetGateway/main/template--etc--sysconfig--network-scripts--net_cnx_up;
touch    InternetGateway/main/script--check-services.pl;
#touch    InternetGateway/main/template--etc--dhcpd.conf;

touch    InternetInterface/main/template--etc--named.conf;
touch    InternetInterface/main/template--etc--rndc.key;
touch    InternetInterface/main/template--etc--rndc.conf;
touch    InternetInterface/main/template--etc--prelude-init.conf;
touch    InternetInterface/main/template--etc--sysconfig--snort
touch    InternetInterface/main/template--etc--snort--snort.conf;
touch    InternetInterface/main/template--etc--snortsnarf.conf;
touch    InternetInterface/main/template--etc--squid--squid.conf;
touch    InternetInterface/main/template--etc--shorewall--shorewall.conf;
#touch    InternetInterface/main/template--etc--iptoip.xml;
touch    InternetInterface/main/template--etc--sysconfig--network;
touch    InternetInterface/main/template--var--www-naat--html--proxy.pac;
touch    InternetInterface/main/script--check-services.pl;

#touch    InternetInterface/main/template--etc--sysconfig--network-scripts--net_cnx_up;
#touch    InternetInterface/main/template--etc--sysconfig--network-scripts--net_cnx_down;
#touch    InternetInterface/main/template--etc--ppp--options;
#touch    InternetInterface/main/template--etc--ppp--ip-up.local;
#touch    InternetInterface/main/template--sbin--ifup-local;
#touch    InternetInterface/main/template--etc--ppp--pap-secrets;
#touch    InternetInterface/main/template--etc--ppp--chap-secrets;
#touch    InternetInterface/main/template--etc--ppp--pppoe.conf;
#touch    InternetInterface/main/template--etc--dhcpd.conf;
touch    HostToPing/main/template--etc--pingtest.conf;

touch    InternetOnBoot/main/script--check-services.pl;

# *** post actions *** 
#touch    InternetAccessType/post/start--bastille-firewall;
touch    InternetAccessType/post/start--adsl
touch    InternetAccessType/post/start--diald
touch    InternetAccessType/post/start--dhcpd
touch    InternetAccessType/post/script--permissions.sh
touch    InternetAccessType/post/start--named
touch    InternetAccessType/post/start--prelude
touch    InternetAccessType/post/restart--network
touch    InternetAccessType/post/restart--shorewall
touch    InternetAccessType/post/restart--ipsec
#touch    InternetAccessType/post/start--iptoip;


touch    InternetInterface/post/script--permissions.sh
touch    InternetInterface/post/start--diald
touch    InternetInterface/post/start--named
touch    InternetInterface/post/start--prelude
touch    InternetInterface/post/start--snortd
touch    InternetInterface/post/start--prelude
touch    InternetInterface/post/start--dhcpd
touch    InternetInterface/post/start--adsl
touch    InternetInterface/post/restart--network
touch    InternetInterface/post/restart--shorewall
touch    InternetInterface/post/start--ipsec

touch    InternetGateway/post/restart--network
touch    InternetGateway/post/restart--shorewall
touch    InternetGateway/post/restart--ipsec
#touch    InternetGateway/post/restart--adsl;

# ------ Dialup ---
for i in DialupConnOffice DialupConnOutside DialupConnWeekend ; do
	mkdir -p $i/{pre,main,post};
	touch $i/pre/stop--diald;
#	touch $i/main/template--etc--diald--diald.conf;
	touch $i/main/template--etc--diald--diald.filter;
#	touch $i/main/template--etc--sysconfig--network-scripts--chat-ppp0;
	touch $i/post/start--diald;
done

# ------ ISDN ------
mkdir -p ISDNDeviceType/{pre,main,post};
mkdir -p ISDNLogin/{pre,main,post};
mkdir -p ISDNPassword/{pre,main,post};
mkdir -p ISDNHomePhone/{pre,main,post};
mkdir -p ISDNProviderDomain/{pre,main,post};
#mkdir -p ISDNZoneName/{pre,main,post};
#mkdir -p ISDNOptions_Interfaces_Shorewall/{pre,main,post};
#mkdir -p ISDNOptions_Hosts_Shorewall/{pre,main,post};
#mkdir -p ISDNRestriction_Shorewall/{pre,main,post};

for i in Driver Protocol Irq Io Io0 Io1 Mem;
do
    [ ! -f ISDN$i ] && ln -s ISDNDeviceType ISDN$i;
done
for i in ProviderPhone Dialing;
do
    [ ! -f ISDN$i ] && ln -s ISDNHomePhone ISDN$i;
done
for i in ProviderDNS1 ProviderDNS2;
do
    [ ! -f ISDN$i ] && ln -s ISDNProviderDomain ISDN$i;
done

# *** pre actions *** 
for i in DeviceType Login Password HomePhone ProviderDomain; 
do
  touch ISDN$i/pre/stop--isdn4linux;
  touch ISDN$i/pre/stop--diald;
done

touch    ISDNProviderDNS1/pre/stop--named;
touch    ISDNProviderDNS1/pre/stop--dhcpd;
touch    ISDNProviderDNS1/pre/stop--snortd;
touch    ISDNProviderDNS1/pre/stop--prelude;
touch    ISDNProviderDomain/pre/stop--named;
touch    ISDNProviderDomain/pre/stop--dhcpd;

# *** main actions *** 


#touch    ISDNZoneName/main/template--etc--shorewall--zones;
#touch    ISDNZoneName/main/template--etc--shorewall--interfaces;
#touch    ISDNZoneName/main/template--etc--shorewall--hosts;
#touch    ISDNZoneName/main/template--etc--shorewall--policy;
#touch    ISDNZoneName/main/template--etc--shorewall--rules;
#touch    ISDNOptions_Interfaces_Shorewall/main/template--etc--shorewall--interfaces;
#touch    ISDNOptions_Hosts_Shorewall/main/template--etc--shorewall--interfaces;
#touch    ISDNZoneName/main/template--etc--shorewall--hosts;
#touch    ISDNRestriction_Shorewall/main/template--etc--shorewall--hosts;
#touch    ISDNOptions_Hosts_Shorewall/main/template--etc--shorewall--hosts;


touch    ISDNDeviceType/main/template--etc--isdn--profile--card--mycard;
touch    ISDNDeviceType/main/script--check-services.pl;

touch    ISDNLogin/main/template--etc--isdn--profile--link--myisp;
touch    ISDNLogin/main/template--etc--ppp--ip-up.local;
touch    ISDNLogin/main/template--sbin--ifup-local;
touch    ISDNLogin/main/template--etc--ppp--pap-secrets;
touch    ISDNLogin/main/template--etc--ppp--chap-secrets;
touch    ISDNLogin/main/script--check-services.pl;

touch    ISDNPassword/main/template--etc--ppp--ip-up.local;
touch    ISDNPassword/main/template--sbin--ifup-local;
touch    ISDNPassword/main/template--etc--ppp--pap-secrets;
touch    ISDNPassword/main/template--etc--ppp--chap-secrets;
touch    ISDNPassword/main/script--check-services.pl;

touch    ISDNHomePhone/main/template--etc--isdn--profile--link--myisp;
touch    ISDNHomePhone/main/script--check-services.pl;

touch    ISDNProviderDomain/main/template--etc--resolv.conf;
touch    ISDNProviderDomain/main/template--etc--named.conf;
touch    ISDNProviderDomain/main/template--etc--rndc.key;
touch    ISDNProviderDomain/main/template--etc--rndc.conf;
touch    ISDNProviderDomain/main/script--check-services.pl;

touch    ISDNProviderDNS1/main/template--etc--resolv.conf;
touch    ISDNProviderDNS1/main/template--etc--named.conf;
touch    ISDNProviderDNS1/main/template--etc--rndc.key;
touch    ISDNProviderDNS1/main/template--etc--rndc.conf;
touch    ISDNProviderDNS1/main/template--etc--dhcpd.conf;
touch    ISDNProviderDNS1/main/template--etc--sysconfig--snort;
touch    ISDNProviderDNS1/main/template--etc--snort--snort.conf;
touch    ISDNProviderDNS1/main/template--etc--snortsnarf.conf;
touch    ISDNProviderDNS1/main/script--check-services.pl;

# *** post actions *** 

touch    ISDNProviderDomain/post/restart--shorewall;
#touch    ISDNProviderDomain/post/start--bastille-firewall;
#touch    ISDNZoneName/post/restart--shorewall;
#touch    ISDNOptions_Interfaces_Shorewall/post/restart--shorewall;
#touch    ISDNRestriction_Shorewall/post/restart--shorewall;
#touch    ISDNOptions_Hosts_Shorewall/post/restart--shorewall;

touch    ISDNProviderDomain/post/script--providers.pl;
touch    ISDNProviderDomain/post/script--permissions.sh;
touch    ISDNProviderDomain/post/start--named;

for i in DeviceType Login Password HomePhone ProviderDomain; 
do
  touch ISDN$i/post/start--isdn4linux;
  touch ISDN$i/post/start--diald; 
  touch ISDN$i/post/script--providers.pl; 
done

touch    ISDNLogin/post/script--providers.pl;
touch    ISDNPassword/post/script--providers.pl;
touch    ISDNProviderDNS1/post/script--providers.pl;
touch    ISDNProviderDNS1/post/start--dhcpd;
touch    ISDNProviderDNS1/post/script--permissions.sh;
touch    ISDNProviderDNS1/post/start--named;
touch    ISDNProviderDNS1/post/start--snortd;
touch    ISDNProviderDNS1/post/start--prelude;
#touch    ISDNProviderDNS1/post/start--bastille-firewall;
touch    ISDNProviderDNS1/post/restart--shorewall;


# ------ Modem ------
mkdir -p PPPDevice/{pre,main,post};

#mkdir -p PPPZoneName/{pre,main,post};
#mkdir -p PPPOptions_Interfaces_Shorewall/{pre,main,post};
#mkdir -p PPPOptions_Hosts_Shorewall/{pre,main,post};
#mkdir -p PPPRestriction_Shorewall/{pre,main,post};

mkdir -p PPPDeviceSpeed/{pre,main,post};
mkdir -p PPPConnectionName/{pre,main,post};
mkdir -p PPPLogin/{pre,main,post};
mkdir -p PPPPassword/{pre,main,post};
mkdir -p PPPProviderDomain/{pre,main,post};
mkdir -p PPPProviderDNS1/{pre,main,post};
mkdir -p PPPProviderPhone/{pre,main,post};
mkdir -p PPPAuth/{pre,main,post};

for i in SpecialCommand;
do
    [ ! -f PPP$i ] && ln -s PPPProviderPhone PPP$i;
done
for i in ProviderDNS2;
do
    [ ! -f PPP$i ] && ln -s PPPProviderDNS1 PPP$i;
done

# *** pre actions *** 

touch PPPProviderDNS1/pre/stop--named;
touch PPPProviderDNS1/pre/stop--dhcpd;
touch PPPProviderDNS1/pre/stop--snortd;
touch PPPProviderDNS1/pre/stop--prelude;

for i in PPPDevice PPPDeviceSpeed PPPProviderPhone PPPLogin PPPPassword PPPProviderDomain \
	 PPPSpecialCommand PPPProviderDNS1 PPPProviderDNS2 ; do
	touch $i/pre/stop--diald;
done

# *** main actions *** 


#touch PPPZoneName/main/template--etc--shorewall--zones;
#touch PPPZoneName/main/template--etc--shorewall--interfaces;
#touch PPPZoneName/main/template--etc--shorewall--hosts;
#touch PPPZoneName/main/template--etc--shorewall--policy;
#touch PPPZoneName/main/template--etc--shorewall--rules;
#touch PPPOptions_Interfaces_Shorewall/main/template--etc--shorewall--interfaces;
#touch PPPZoneName/main/template--etc--shorewall--hosts;
#touch PPPRestriction_Shorewall/main/template--etc--shorewall--hosts;
#touch PPPOptions_Hosts_Shorewall/main/template--etc--shorewall--hosts;


#/etc/diald/diald.conf
#/etc/diald/diald.filter
touch PPPAuth/main/template--etc--ppp--ip-up.local;
touch PPPAuth/main/template--sbin--ifup-local;
touch PPPAuth/main/template--etc--ppp--pap-secrets;
touch PPPAuth/main/template--etc--ppp--chap-secrets;
touch PPPAuth/main/template--etc--sysconfig--network-scripts--chat-ppp0;
touch PPPAuth/main/script--check-services.pl;

#touch PPPDevice/main/template--etc--sysconfig--network-scripts--ifcfg-ppp0;
touch PPPDevice/main/template--etc--diald--diald.conf;
touch PPPDevice/main/script--check-services.pl;

touch PPPDeviceSpeed/main/template--etc--sysconfig--network-scripts--ifcfg-ppp0;
touch PPPDeviceSpeed/main/template--etc--diald--diald.conf;
touch PPPDeviceSpeed/main/script--check-services.pl;

touch PPPLogin/main/template--etc--ppp--options;
touch PPPLogin/main/template--etc--ppp--ip-up.local;
touch PPPLogin/main/template--sbin--ifup-local;
touch PPPLogin/main/template--etc--ppp--pap-secrets;
touch PPPLogin/main/template--etc--ppp--chap-secrets;
touch PPPLogin/main/template--etc--sysconfig--network-scripts--chat-ppp0;
touch PPPLogin/main/template--etc--sysconfig--network-scripts--ifcfg-ppp0;
touch PPPLogin/main/script--check-services.pl;

touch PPPPassword/main/template--etc--sysconfig--network-scripts--chat-ppp0;
touch PPPPassword/main/template--etc--ppp--ip-up.local;
touch PPPPassword/main/template--sbin--ifup-local;
touch PPPPassword/main/template--etc--ppp--pap-secrets;
touch PPPPassword/main/template--etc--ppp--chap-secrets;
touch PPPPassword/main/script--check-services.pl;

touch PPPProviderDomain/main/template--etc--resolv.conf;
touch PPPProviderDomain/main/script--check-services.pl;

touch PPPProviderDNS1/main/template--etc--resolv.conf;
touch PPPProviderDNS1/main/template--etc--named.conf;
touch PPPProviderDNS1/main/template--etc--rndc.key;
touch PPPProviderDNS1/main/template--etc--rndc.conf;
touch PPPProviderDNS1/main/template--etc--dhcpd.conf;
touch PPPProviderDNS1/main/template--etc--sysconfig--snort;
touch PPPProviderDNS1/main/template--etc--snort--snort.conf;
touch PPPProviderDNS1/main/template--etc--snortsnarf.conf;
touch PPPProviderDNS1/main/script--check-services.pl;
touch PPPProviderDNS1/main/template--etc--sysconfig--network-scripts--ifcfg-ppp0;

touch PPPProviderPhone/main/template--etc--sysconfig--network-scripts--chat-ppp0;
touch PPPProviderPhone/main/script--check-services.pl;

# *** post actions *** 

for i in PPPDevice PPPDeviceSpeed PPPProviderPhone PPPLogin PPPPassword PPPProviderDomain \
	 PPPSpecialCommand PPPProviderDNS1 PPPProviderDNS2 ; do
	touch $i/post/start--diald;
	#touch $i/post/start--bastille-firewall
	touch $i/post/restart--shorewall
	touch $i/post/script--providers.pl
done


#touch PPPZoneName/post/restart--shorewall;
#touch PPPOptions_Interfaces_Shorewall/post/restart--shorewall;
#touch PPPOptions_Hosts_Shorewall/post/restart--shorewall;
#touch PPPRestriction_Shorewall/post/restart--shorewall;

touch PPPProviderDNS1/post/script--permissions.sh;
touch PPPProviderDNS1/post/start--named;
touch PPPProviderDNS1/post/start--dhcpd;
touch PPPProviderDNS1/post/start--snortd;
touch PPPProviderDNS1/post/start--prelude;

# ------ ADSL ------
mkdir -p ADSLLogin/{pre,main,post};
mkdir -p ADSLCountry/{pre,main,post};
mkdir -p ADSLPassword/{pre,main,post};
mkdir -p ADSLPhysicalInterface/{pre,main,post};
mkdir -p ADSLProviderDomain/{pre,main,post};
mkdir -p ADSLProviderDNS1/{pre,main,post};
ln -s    ADSLProviderDNS1  ADSLProviderDNS2;
mkdir -p ADSLType/{pre,main,post};
mkdir -p ADSLAutomaticReconnect/{pre,main,post};
ln -s    ADSLAutomaticReconnect ADSLAutomaticReconnectDelay;

# *** pre actions *** 
touch    ADSLProviderDNS1/pre/stop--named;
touch    ADSLProviderDNS1/pre/stop--dhcpd;
touch    ADSLProviderDNS1/pre/stop--snortd;
touch    ADSLProviderDNS1/pre/stop--prelude;

# *** main actions *** 

touch    ADSLPhysicalInterface/main/template--etc--shorewall--zones;
touch    ADSLPhysicalInterface/main/template--etc--shorewall--hosts;
touch    ADSLPhysicalInterface/main/template--etc--shorewall--interfaces;
touch    ADSLPhysicalInterface/main/template--etc--shorewall--rules;
touch    ADSLPhysicalInterface/main/script--check-services.pl;

touch    ADSLLogin/main/template--etc--ppp--ip-up.local;
touch    ADSLLogin/main/template--sbin--ifup-local;
touch    ADSLLogin/main/template--etc--ppp--pap-secrets;
touch    ADSLLogin/main/template--etc--ppp--chap-secrets;
touch    ADSLLogin/main/template--etc--ppp--peers--adsl;
touch    ADSLLogin/main/template--etc--ppp--pppoe.conf;
touch    ADSLLogin/main/template--etc--sysconfig--network-scripts--net_cnx_up;
touch    ADSLLogin/main/script--check-services.pl;
#touch    ADSLLogin/main/template--etc--ppp--options;
#touch    ADSLLogin/main/template--etc--sysconfig--network-scripts--net_cnx_down;
touch    ADSLCountry/main/template--etc--ppp--peers--adsl;
touch    ADSLPassword/main/template--etc--ppp--ip-up.local;
touch    ADSLPassword/main/template--sbin--ifup-local;
touch    ADSLPassword/main/template--etc--ppp--pap-secrets;
touch    ADSLPassword/main/template--etc--ppp--chap-secrets;
touch    ADSLPassword/main/script--check-services.pl;
#ttouch    ADSLPhysicalInterface/main/template--etc--Bastille--bastille-firewall.cfg
touch    ADSLPhysicalInterface/main/template--etc--ppp--pppoe.conf
touch    ADSLPhysicalInterface/main/template--etc--squid--squid.conf
touch    ADSLPhysicalInterface/main/script--check-services.pl
touch    ADSLProviderDNS1/main/template--etc--resolv.conf;
touch    ADSLProviderDNS1/main/template--etc--named.conf;
touch    ADSLProviderDNS1/main/template--etc--rndc.key;
touch    ADSLProviderDNS1/main/template--etc--rndc.conf;
touch    ADSLProviderDNS1/main/template--etc--dhcpd.conf;
touch    ADSLProviderDNS1/main/template--etc--sysconfig--snort;
touch    ADSLProviderDNS1/main/template--etc--snort--snort.conf;
touch    ADSLProviderDNS1/main/template--etc--snortsnarf.conf;
touch    ADSLProviderDNS1/main/script--check-services.pl;
#touch ADSLProviderDNS1/main/template--etc--Bastille--bastille-firewall.cfg;
touch    ADSLProviderDomain/main/template--etc--resolv.conf;
touch    ADSLProviderDomain/main/script--check-services.pl;
#ttouch    ADSLType/main/template--etc--Bastille--bastille-firewall.cfg
touch    ADSLType/main/template--etc--ppp--chap-secrets;
touch    ADSLType/main/template--etc--ppp--options;
touch    ADSLType/main/template--etc--ppp--ip-up.local;
touch    ADSLType/main/template--sbin--ifup-local;
touch    ADSLType/main/template--etc--ppp--pap-secrets;
touch    ADSLType/main/template--etc--ppp--peers--adsl;
#touch    ADSLType/main/template--etc--ppp--pppoe.conf;
touch    ADSLType/main/template--etc--sysconfig--network-scripts--net_cnx_up;
touch    ADSLType/main/template--etc--sysconfig--network-scripts--net_cnx_down;
touch    ADSLType/main/script--check-services.pl;


# *** post actions *** 

touch    ADSLPhysicalInterface/post/restart--shorewall;

#touch    ADSLProviderDNS1/post/start--bastille-firewall;
touch    ADSLProviderDNS1/post/script--permissions.sh;
touch    ADSLProviderDNS1/post/restart--shorewall;
touch    ADSLProviderDNS1/post/start--named;
touch    ADSLProviderDNS1/post/start--dhcpd;
touch    ADSLProviderDNS1/post/start--snortd;
touch    ADSLProviderDNS1/post/start--prelude;
touch    ADSLProviderDNS1/post/script--providers.pl;
touch    ADSLPassword/post/script--providers.pl;
touch    ADSLLogin/post/script--providers.pl;

touch    ADSLProviderDomain/post/script--providers.pl;
touch    ADSLAutomaticReconnect/post/script--adsl-auto-reconnect.pl;

# ------ Monitoring -------------
mkdir -p MONITORINGEnabled/{pre,main,post}

# *** pre actions *** 

# *** main actions *** 

touch	MONITORINGEnabled/main/script--monitoring--activate.pl

# *** post actions *** 


# ------ Tools -----------------
mkdir -p RemoteSshIP/{pre,main,post}
touch RemoteSshIP/main/template--var--www-naat--html--en--secure--jar--jta20--applet.conf;
touch RemoteSshIP/main/script--permissions.sh;


# copy all events in the system
popd;
# See if we can keep links with rpm...
#cp -dRf events $1/usr/share/naat/
cp -Rf events $1/usr/share/naat/;

#find $1/usr/share/naat/events -name CVS -exec rm -Rf {} \; 2>/dev/null
